@@ -559,6 +559,32 @@ class EnvBase(ABC):
                 self.pool_token_supply_ledger[contract]['supply'].append(self.pool_token_supply_ledger[contract]['supply'][-1])
         return (y)
 
+    def check_pool_shutdown(self):
+        """Checks if any whitelisted tokens meet the pool-shutdown criterea, and resets the DOAmsig state if yes.
+
+        Returns:
+            self
+        """
+        dao_msig_initialized_pools = self.dao_msig_initialized_pools
+        for TKN in self.whitelisted_tokens:
+            BNTperTKN = self.get_bnt_rate(TKN)
+            if self.vault_ledger[TKN][-1] * BNTperTKN < self.min_liquidity_threshold and (TKN in self.dao_msig_initialized_pools):
+
+                dao_msig_initialized_pools = [token for token in dao_msig_initialized_pools if token != TKN]
+                self.available_liquidity_ledger[TKN]['BNT'].append(0)
+                self.available_liquidity_ledger[TKN][TKN].append(0)
+                self.available_liquidity_ledger[TKN]['funding_limit'].append(self.bnt_funding_limit)
+                self.available_liquidity_ledger[TKN]['block_num'].append(
+                    self.available_liquidity_ledger[TKN]['block_num'][-1])
+                self.dao_msig_initialized_pools = dao_msig_initialized_pools
+
+                if self.verbose:
+                    print(
+                        f"WARNING POOL SHUTDOWN!!! \n",
+                        f"pool={TKN} \n",
+                        f"TKN Liquidity <= Minimum Pool Liquidity, resetting pool to pre-DAOmsig state"
+                    )
+
     def check_bootstrapped_tokens(self):
         """Checks if new tokens have been whitelisted and whether or not those token meet the min_liquidity_threshold,
         ensures token are added to the bootstrapped_tokens list if any whitelisted tokens meet this criterea
